"""Top-level package for IX-F Scraper."""

__author__ = """Alfie Foster"""
__email__ = 'bonzi@as207960.net'
__version__ = '0.0.2'

from .ASNInfo import ASNInfo
from .csvWrite import csvWrite
from .macLookup import macLookup



import json
import csv
import os
import requests
from pprint import pprint
from networktoolkit import vendorlookup
from ipaddress import IPv4Address, IPv6Address, ip_address

# asn,ip,mac,speed,state,as-macro


def ASNInfo(asn: int, ixf: str):

    try:
        request = requests.get(ixf)
        request.raise_for_status()
    except (
        requests.ConnectionError,
        requests.RequestException,
        requests.HTTPError,
        requests.Timeout,
        requests.TooManyRedirects,
    ) as e:
        raise e

    data = request.json()

    for member in data["member_list"]:
        if member["asnum"] != asn:
            continue
        else:
            return member

    raise ValueError("ASN does not exist in provided IX-F file")



import json
import csv
import os
import requests
import ASNInfo
from pprint import pprint
from networktoolkit import vendorlookup
from ipaddress import IPv4Address, IPv6Address, ip_address


def csvWrite(asn: int, ip: str, mac: str, vendor: str):

    ipSanitised = ip_address(address=ip)

    if type(ipSanitised) is IPv4Address or IPv6Address:
        fileEmpty = os.stat("output.csv").st_size == 0
        try:
            with open("output.csv", mode="a") as csvOutput:
                # asn,ip,mac,speed,state,as-macro
                fieldnames = [
                    "asn",
                    "ip",
                    "mac",
                    "vendor",
                    "speed",
                    "state",
                    "as-macro",
                ]
                csvWriter = csv.DictWriter(csvOutput, fieldnames=fieldnames,)

                if fileEmpty:
                    csvWriter.writeheader()  # file doesn't exist yet, write a header

                csvWriter.writerow(
                    {"asn": asn, "ip": ipSanitised, "mac": mac, "vendor": vendor}
                )

        except (
            OSError,
            FileExistsError,
            PermissionError,
            UnicodeError,
            ValueError,
        ) as e:
            raise e


def ipLookup(asn: int, ixf: str):
    return


# Shit

# for connection in member["connection_list"]:
#     print("ASN connection")
#     # pprint(connection)
#     for vlan in connection["vlan_list"]:
#         print("ASN VLAN")
#         # pprint(vlan)
#         # for ipVersion, ipData in vlan.items():
#         for ipVersion, ipData in vlan.items():
#             if ipVersion == "vlan_id":
#                 pass
#             else:
#                 print("ASN Port Info per IP Version")
#                 #                pprint(f"{ipVersion}: {ipData}")
#                 # pprint(ipData)
#                 print(ipData["address"])
#                 for mac in ipData["mac_addresses"]:
#                     mac_vendor = vendorlookup.lookup_vendor(mac)
#                     if mac_vendor is not None:
#                         info = f"{member['asnum']} {mac} {mac_vendor}"
#                         print(info)
#                     else:
#                         info = f"{member['asnum']} {mac} Unknown"
#                         print(info)

#                     return info
#                     # csvWrite(member['asnum'], ipData["address"], mac)

#    else:
#        pprint(data["member_list"])
#        raise ValueError("ASN may be invalid or does not exist in IXF File")



import json
import csv
import os
import requests
import ASNInfo
import csvWrite
from pprint import pprint
from networktoolkit import vendorlookup
from ipaddress import IPv4Address, IPv6Address, ip_address


def macLookup(asn: int, ixf: str):

    info = dict()

    member = ASNInfo(asn=asn, ixf=ixf)

    for connection in member["connection_list"]:
        for vlan in connection["vlan_list"]:
            for ipVersion, ipData in vlan.items():
                if ipVersion == "vlan_id":
                    pass
                else:
                    print(ipData["address"])
                    try:
                        ip = ip_address(ipData["address"])
                    except ValueError as e:
                        return e

                    if type(ip) is IPv4Address:
                        for mac in ipData["mac_addresses"]:
                            mac_vendor = vendorlookup.lookup_vendor(mac)
                            if mac_vendor is not None:
                                csvWrite(
                                    asn=member["asnum"],
                                    ip=ipData["address"],
                                    mac=mac,
                                    vendor=mac_vendor,
                                )
                                info["v4"] = {
                                    "asn": member["asnum"],
                                    "ip": ipData["address"],
                                    "mac": mac,
                                    "vendor": mac_vendor,
                                }
                            else:
                                csvWrite(
                                    asn=member["asnum"],
                                    ip=ipData["address"],
                                    mac=mac,
                                    vendor="Unknown",
                                )
                                info["v4"] = {
                                    "asn": member["asnum"],
                                    "ip": ipData["address"],
                                    "mac": mac,
                                    "vendor": "Unknown",
                                }
                    elif type(ip) is IPv6Address:
                        for mac in ipData["mac_addresses"]:
                            mac_vendor = vendorlookup.lookup_vendor(mac)
                            if mac_vendor is not None:
                                csvWrite(
                                    asn=member["asnum"],
                                    ip=ipData["address"],
                                    mac=mac,
                                    vendor=mac_vendor,
                                )
                                info["v6"] = {
                                    "asn": member["asnum"],
                                    "ip": ipData["address"],
                                    "mac": mac,
                                    "vendor": mac_vendor,
                                }
                            else:
                                csvWrite(
                                    asn=member["asnum"],
                                    ip=ipData["address"],
                                    mac=mac,
                                    vendor="Unknown",
                                )
                                info["v6"] = {
                                    "asn": member["asnum"],
                                    "ip": ipData["address"],
                                    "mac": mac,
                                    "vendor": "Unknown",
                                }
                    # else:
                    #    raise ValueError()

            return info

            # if mac_vendor is not None:
            #     print(f"{member['asnum']} {ipAddr} {mac} {mac_vendor}")
            # else:
            #     print(f"{member['asnum']} {ipAddr} {mac} Unknown")

    #                for ipDetails in (
    #                    ipData.items() if ipVersion == "ipv4" or ipVersion == "ipv6" else []
    #                ):
    #                    print("ASN IP Details")
    #                    pprint(ipDetails)
    #                    for mac in ipDetails["mac_addresses"]:
    #                        pprint(mac)


#        for peerASN, peerDetails in (
#            ixDetails["peers"].items() if ixDetails["peers"] else []
#        ):
